==> gradle-src-2.14.1-1-any.pkg.tar.xz: usr/share/java/gradle/src/plugins/org/gradle/api/plugins/WarPluginConvention.java <==
/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.plugins;

import groovy.lang.GroovyObjectSupport;
import org.gradle.api.Project;

import java.io.File;

/**
 * <p>A {@link Convention} used for the WarPlugin.</p>
 */
public class WarPluginConvention extends GroovyObjectSupport {
    private String webAppDirName;
    private final Project project;

    public WarPluginConvention(Project project) {
        this.project = project;
        webAppDirName = "src/main/webapp";
    }

    /**
     * Returns the web application directory.
     */
    public File getWebAppDir() {
        return project.file(webAppDirName);
    }

    /**
     * The name of the web application directory, relative to the project directory.
     */
    public String getWebAppDirName() {
        return webAppDirName;
    }

    public void setWebAppDirName(String webAppDirName) {
        this.webAppDirName = webAppDirName;
    }

    public final Project getProject() {
        return project;
    }
}

==> gradle-src-4.10-1-any.pkg.tar.xz: usr/share/java/gradle/src/plugins/org/gradle/api/plugins/WarPluginConvention.java <==
/*
 * Copyright 2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.plugins;

import org.gradle.api.Project;
import org.gradle.util.DeprecationLogger;

import java.io.File;

/**
 * <p>A {@link Convention} used for the WarPlugin.</p>
 */
public class WarPluginConvention {
    private String webAppDirName;
    private final Project project;

    /**
     * Creates a {@link WarPluginConvention}.
     *
     * @deprecated Creating instances of this class is deprecated. These should be created by the WAR plugin only.
     */
    @Deprecated
    public WarPluginConvention(Project project) {
        DeprecationLogger.nagUserOfDeprecated("Creating instances of WarPluginConvention");
        this.project = project;
        webAppDirName = "src/main/webapp";
    }

    /**
     * Returns the web application directory.
     */
    public File getWebAppDir() {
        return project.file(webAppDirName);
    }

    /**
     * The name of the web application directory, relative to the project directory.
     */
    public String getWebAppDirName() {
        return webAppDirName;
    }

    public void setWebAppDirName(String webAppDirName) {
        this.webAppDirName = webAppDirName;
    }

    public final Project getProject() {
        return project;
    }
}
